import json
import traceback
from fastapi import FastAPI, Request

app = FastAPI()

INISGHTS_MAP = {}


def _get_bearer(request: Request) -> str:
    req_headers = request.headers
    print(f"===> headers? {req_headers}")
    return req_headers.get("authorization")


def _save_payload(payload):
    with open('/code/data/payloads.json', 'a') as f:
        f.write(f'{payload}\n')


@app.api_route("/{path_name:path}", methods=["POST","GET"])
async def catch_all(request: Request, path_name: str):
    """
    curl -d '{"foo":"bar"}' -H "Content-Type: application/json" -X POST http://localhost:9003/foo
    """
    try:
        req_body = await request.json()
        print(_get_bearer(request))
        req_body_str = json.dumps(req_body) # JSON string
        print(f"===> INIT request.method {request.method} path_name: {path_name}\nreq_body:{req_body_str}\n")
        _save_payload(req_body_str)
    except Exception as exc:
        print(f"!!! {str(exc)}")
        traceback.print_exc()
        # https://www.starlette.io/requests/
        req_body_bytes = await request.body()
        req_body_str = str(req_body_bytes.decode())
        req_body_len = len(req_body_str)
        print(f"!!! not JSON req body? '{req_body_str}': len? {req_body_len}")
        pass
    return {}



import time
from airflow.contrib.operators.bigquery_operator import BigQueryOperator
from airflow.providers.google.cloud.operators.bigquery import BigQueryInsertJobOperator, BigQueryExecuteQueryOperator
from typing import List, Any, Union, NoReturn, Optional  # noqa: F401
from airflow.utils.log.logging_mixin import LoggingMixin  # type: ignore
from airflow.models import DAG
from airflow.utils.dates import days_ago
from datetime import timedelta

log = LoggingMixin().log

args = {
    'owner': 'airflow',
    'start_date': days_ago(10)
}

dag = DAG(
    dag_id='bigq_demo', default_args=args,
    schedule_interval='0 0 1 * *',
    dagrun_timeout=timedelta(minutes=60))

task1 = BigQueryInsertJobOperator(
    dag=dag,
    task_id="task1",
    configuration={
        "query": {
            "query": "INSERT bigquery_demo.top_rising_term_max_min_airflow (region, term_name, score) SELECT region, term_name, cast(term_index as STRING), FROM bigquery_demo.top_rising_term_highest UNION ALL SELECT region, term_name, cast(term_index as STRING), FROM `alvinai.bigquery_demo.top_rising_term_lowest` limit 1",
            "useLegacySql": False,
        }
    }
)

task2 = BigQueryExecuteQueryOperator(
    dag=dag,
    task_id="task2",
    use_legacy_sql=False,
    sql="INSERT bigquery_demo.top_rising_term_region_airflow (region, term, term_index,term_gain) SELECT dma_name, term, cast(score as String), cast(percent_gain as String) FROM bigquery_demo.top_rising_term limit 1"
)

task3 = BigQueryOperator(
    dag=dag,
    task_id="task3",
    use_legacy_sql=False,
    sql="INSERT bigquery_demo.top_rising_term_max_min_airflow (region, term_name, score) SELECT region, term_name, cast(term_index as STRING), FROM bigquery_demo.top_rising_term_highest UNION ALL SELECT region, term_name, cast(term_index as STRING), FROM `alvinai.bigquery_demo.top_rising_term_lowest` limit 1"
)
task1 >> task2 >> task3



from datetime import datetime, timedelta

from airflow.exceptions import AirflowException
from airflow.models import DAG
from airflow.operators.python import PythonOperator

seven_days_ago = datetime.combine(
    datetime.today() - timedelta(7), datetime.min.time()
)  # noqa

args = {
    "owner": "airflow",
    "start_date": seven_days_ago,
}


def raise_exception():
    raise AirflowException("This task has failed.")


def print_log():
    print("Task executed successfully")


####################################################################################
# DAG with one task that should fail. Dag should fail.
####################################################################################
dag_simple_task_failure = DAG(
    dag_id="simgle_task_failure", default_args=args, schedule_interval=None
)  # noqa

fail_task = PythonOperator(
    task_id="raise_exception",
    provide_context=True,
    python_callable=raise_exception,
    dag=dag_simple_task_failure,
)

####################################################################################
# DAG with one task that should succeed. Dag should succeed
####################################################################################

dag_simple_task_success = DAG(
    dag_id="simgle_task_success", default_args=args, schedule_interval=None
)  # noqa

sucess_task = PythonOperator(
    task_id="print_log",
    provide_context=True,
    python_callable=print_log,
    dag=dag_simple_task_success,
)

####################################################################################
# DAG with two failed tasks that should fail. Dag should fail.
####################################################################################

dag_double_task_fail = DAG(
    dag_id="double_task_fail", default_args=args, schedule_interval=None
)  # noqa

fail_task_two = PythonOperator(
    task_id="raise_exception_two",
    provide_context=True,
    python_callable=raise_exception,
    dag=dag_double_task_fail,
)

fail_task_three = PythonOperator(
    task_id="raise_exception_three",
    provide_context=True,
    python_callable=raise_exception,
    dag=dag_double_task_fail,
)


####################################################################################
# DAG with one failed task and one succeed task. DAG should fail.
####################################################################################

dag_double_task_fail = DAG(
    dag_id="double_task_mix", default_args=args, schedule_interval=None
)  # noqa

mix_task_fail = PythonOperator(
    task_id="raise_exception_four",
    provide_context=True,
    python_callable=raise_exception,
    dag=dag_double_task_fail,
)

mix_task_success = PythonOperator(
    task_id="print_log_two",
    provide_context=True,
    python_callable=print_log,
    dag=dag_double_task_fail,
)


####################################################################################
# DAG with two succeed tasks. DAG should succeed.
####################################################################################

dag_double_task_succeed = DAG(
    dag_id="double_task_success", default_args=args, schedule_interval=None
)  # noqa

task_success_one = PythonOperator(
    task_id="print_log_four",
    provide_context=True,
    python_callable=print_log,
    dag=dag_double_task_succeed,
)

task_success_two = PythonOperator(
    task_id="print_log_five",
    provide_context=True,
    python_callable=print_log,
    dag=dag_double_task_succeed,
)



import logging
from datetime import timedelta
from typing import Any  # noqa: F401

from airflow.models import DAG
from airflow.contrib.operators.snowflake_operator import SnowflakeOperator
from airflow.utils.dates import days_ago

logging.warning("Inside the DAG")

args = {"owner": "airflow", "start_date": days_ago(10)}

dag = DAG(
    dag_id="snowflake_dag",
    default_args=args,
    schedule_interval="0 0 1 * *",
    dagrun_timeout=timedelta(minutes=60),
)


task_snowflake = SnowflakeOperator(
    dag=dag,
    task_id="task_snowflake",
    sql="SELECT 1;",
    snowflake_conn_id='snowflake_db',
)



import setuptools

__base_version__ ="0.15.3"
__version__ ="0.15.3-rc.0"

requirements = ["gorilla==0.4.0", "openlineage-airflow==0.6.1"]

setuptools.setup(
    name="alvin_integration",
    version=__version__,
    author="Alvin",
    author_email="tech@alvin.ai",
    description="Alvin lineage python library for integrations",
    packages=setuptools.find_packages(),
    install_requires=requirements,
    python_requires=">=3.7",
)



import pkg_resources
from alvin_integration.producers.airflow.installer import AlvinAirflowInstaller
from alvin_integration.producers.airflow.config import AirflowProducerConfig


def test_setup_airflow_installer():

    alvin_airflow_installer = AlvinAirflowInstaller()

    assert alvin_airflow_installer.host_package_map == {'apache-airflow': pkg_resources.get_distribution('apache-airflow')}

    assert type(alvin_airflow_installer.provider_config) == AirflowProducerConfig

    assert alvin_airflow_installer.provider_config.producer_name == 'Airflow'



"""
Alvin Package for Airflow

This plugin contains the installation necessary to
integrate Airflow with Alvin platform.
"""

import logging

from airflow.plugins_manager import AirflowPlugin

from alvin_integration.producers.airflow.installer import AlvinAirflowInstaller

from alvin_integration.helper import AlvinLoggerAdapter
log = AlvinLoggerAdapter(logging.getLogger(__name__), {})

alvin_manager = AlvinAirflowInstaller()

alvin_manager.install()


class AlvinAirflowPatch(AirflowPlugin):
    name = "alvin_airflow_plugin"



import logging
from datetime import timedelta
from typing import Any  # noqa: F401

from airflow.models import DAG
from airflow.providers.google.cloud.operators.bigquery import (
    BigQueryExecuteQueryOperator,
    BigQueryInsertJobOperator
)
from airflow.utils.dates import days_ago

logging.warning("Inside the DAG")

args = {"owner": "airflow", "start_date": days_ago(10)}

dag = DAG(
    dag_id="bigquery_dag_airflow_v2",
    default_args=args,
    schedule_interval="0 0 1 * *",
    dagrun_timeout=timedelta(minutes=60),
)

# On GCP Compose "bigquery_default" works, so we call it like this
# instead of "test_fernet"
ALVIN_GCP_CONN_ID = "bigquery_default"


def task_failure_func(context):
    print(f"Alvin callback - {task_failure_func.__name__}: {context}")


def task_success_func(context):
    print(f"Alvin callback - {task_success_func.__name__}: {context}")


def task_retry_func(context):
    print(f"Alvin callback - {task_retry_func.__name__}: {context}")


BQ_SQL_QUERY = "SELECT * FROM alvin_test_dataset_eu.WineQualityEU"


task_bq_af_v2 = BigQueryExecuteQueryOperator(
    dag=dag,
    task_id="task_bq_af_v2",
    sql=BQ_SQL_QUERY,
    gcp_conn_id=ALVIN_GCP_CONN_ID,
    on_failure_callback=task_failure_func,
    on_success_callback=task_success_func,
    on_retry_callback=task_retry_func,
)


task_bq_af_v2_2 = BigQueryExecuteQueryOperator(
    dag=dag,
    task_id="task_bq_af_v2_2",
    sql=BQ_SQL_QUERY,
    gcp_conn_id=ALVIN_GCP_CONN_ID,
    on_failure_callback=task_failure_func,
    on_success_callback=task_success_func,
    on_retry_callback=task_retry_func,
)
task_bq_af_v2 >> task_bq_af_v2_2



import time
from airflow.providers.snowflake.operators.snowflake import SnowflakeOperator
from typing import List, Any, Union, NoReturn, Optional  # noqa: F401
from airflow.utils.log.logging_mixin import LoggingMixin  # type: ignore
from airflow.models import DAG
from airflow.utils.dates import days_ago
from datetime import timedelta

log = LoggingMixin().log
SNOWFLAKE_CONN_ID = 'snowflake_db'

args = {
    'owner': 'airflow',
    'start_date': days_ago(10),
    'snowflake_conn_id': SNOWFLAKE_CONN_ID
}

dag = DAG(
    dag_id='snowflake_demo',
    default_args=args,
    schedule_interval='0 0 1 * *',
    dagrun_timeout=timedelta(minutes=60)
)


task1 = SnowflakeOperator(
    task_id='task1',
    dag=dag,
    sql='SELECT SYMBOL FROM "FINSERVAM"."PROD"."FRAUDULENT_TRADE" limit 1',
    warehouse='COMPUTE_WH',
    database='FINSERVAM',
    schema='PROD',
    role='ACCOUNTADMIN'
)

task2 = SnowflakeOperator(
    task_id='task2',
    dag=dag,
    sql='create or replace table fraudulent_trade_airflow as (select date, symbol, exchange, action, close, trader, pm, 0 as fraud from "FINSERVAM"."PROD"."TRADE")',
    warehouse='COMPUTE_WH',
    database='FINSERVAM',
    schema='PROD',
    role='ACCOUNTADMIN'
)


task1 >> task2
